==============================
Introduction
==============================

.. contents::


Description
============

This package will add a viewlet on Images with links to edit an image on external webservices.

The activation of those services is controlled by settings in a specific control panel on the plone site setup.


Currently, we support only pixlr but we plan to add fotoflexer and aviary.

You can view a `Demo <http://www.youtube.com/watch?v=tCCJelVmYOE>`_.


Credits
========
Companies
---------
|makinacom|_

  * `Planet Makina Corpus <http://www.makina-corpus.org>`_
  * `Contact us <mailto:python@makina-corpus.org>`_

.. |makinacom| image:: http://depot.makina-corpus.org/public/logo.gif
.. _makinacom:  http://www.makina-corpus.com

Authors
------------

- kiorky  <kiorky@cryptelium.net>

Contributors
-----------------


Repository
------------

- `GITHUB <https://github.com/collective/collective.externalimageeditor>`-


TODO
=====
- integrate plone.protect in services url callbacks to protect image integration from CSRF attacks.
- integrate some others services:

      - fotoflexer
      - aviary


